@@ -1,7 +1,9 @@
 from sacrerouge.metrics.metric import DocumentBasedMetric, Metric, ReferenceBasedMetric, ReferenceFreeMetric, SummaryBasedMetric
+from sacrerouge.metrics.apes import APES
 from sacrerouge.metrics.autosummeng import AutoSummENG
 from sacrerouge.metrics.bertscore import BertScore
 from sacrerouge.metrics.bewte import BEwTE
+from sacrerouge.metrics.blanc import Blanc
 from sacrerouge.metrics.bleurt import Bleurt
 from sacrerouge.metrics.decomposed_rouge import DecomposedRouge
 from sacrerouge.metrics.meteor import Meteor
